@@ -306,6 +306,12 @@ public Q_SLOTS:
     bool showIncidence(Akonadi::Item::Id id);
     void showIncidence();
 
+    /**
+     * Create a read-only viewer dialog for the occurrence of the
+     * supplied incidence on the given date.
+     */
+    void showOccurrence(const Akonadi::Item &, const QDate &);
+
     /**
       Show an incidence in context. This means showing the todo, agenda or
       journal view (as appropriate) and scrolling it to show the incidence.
