@@ -11,7 +11,6 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-
 #include "korganizer.h"
 #include "actionmanager.h"
 #include "calendarview.h"
@@ -35,7 +34,11 @@
 #include <QLabel>
 #include <QStatusBar>
 #include <QVBoxLayout>
-#ifdef WITH_KUSERFEEDBACK
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/activitiesmanager.h"
+#include "prefs/koprefs.h"
+#endif
+#if KORGANIZER_WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 
 #include <KUserFeedback/NotificationPopup>
@@ -70,10 +73,14 @@ KOrganizer::KOrganizer()
     mActionManager = new ActionManager(this, mCalendarView, this, this, false, menuBar(), toolBar());
     (void)new KOrganizerIfaceImpl(mActionManager, this, QStringLiteral("IfaceImpl"));
 
-#ifdef WITH_KUSERFEEDBACK
+#if KORGANIZER_WITH_KUSERFEEDBACK
     auto userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
     userFeedBackNotificationPopup->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
 #endif
+
+#if HAVE_ACTIVITY_SUPPORT
+    ActivitiesManager::self()->setEnabled(KOPrefs::instance()->enabledActivities());
+#endif
 }
 
 KOrganizer::~KOrganizer()
